export declare type Comparator<T> = (a: Readonly<T>, b: Readonly<T>) => -1 | 0 | 1;
export declare type ComparatorKey<T> = (item: Readonly<T>) => string | number;
export declare const empty: ReadonlyArray<never>;
/**
 * Build a sort comparator suitable for use with arrays of objects.
 *
 * @param key return the sortable value for an object.
 */
export declare function sortComparatorDesc<T>(key: ComparatorKey<T>): Comparator<T>;
/**
 * Build a sort comparator suitable for use with arrays of objects.
 *
 * @param key return the sortable value for an object.
 */
export declare function sortComparatorAsc<T>(key: ComparatorKey<T>): Comparator<T>;
export declare function sorted<T>(array: ReadonlyArray<T>, key: ComparatorKey<T>, makeComparator?: typeof sortComparatorDesc): T[];
export declare function omitIndex<T>(array: ReadonlyArray<T>, index: number): Array<T>;
export declare function omitOne<T>(array: ReadonlyArray<T>, predicate: (item: T) => boolean): ReadonlyArray<T>;
export declare function omitNulls<T>(items: ReadonlyArray<T>): ReadonlyArray<NonNullable<T>>;
export declare function reduceOmitNulls<T>(accum: ReadonlyArray<NonNullable<T>>, curr: T): ReadonlyArray<NonNullable<T>>;
/**
 * Returns an array with an item appended, if it is not already the last item in the array.
 */
export declare function appendedIfNotAlready<T>(array: ReadonlyArray<T>, item: T): ReadonlyArray<T>;
/**
 * Build a filter function that filters an array of items based on a property of
 * each item.
 *
 * Example:
 *
 *     const items = [
 *       { id: 'a', value: 'foo' },
 *       { id: 'a', value: 'bar' },
 *       { id: 'b', value: 'baz' },
 *     ];
 *     items.filter(filterUnique(item => item.id))
 *     // returns [{ id: 'a', value: 'foo' }, { id: 'b', value: 'baz' }]
 */
export declare function filterUnique<Item, Prop>(key: (item: Readonly<Item>) => Prop): (item: Item) => boolean;
/**
 * Return an array of keys, given an object.
 */
export declare function keys<T>(hash: Readonly<T>): (keyof T)[];
export declare function sortedIndex<T>(array: ReadonlyArray<T>, element: Readonly<T>, comparators: ReadonlyArray<Comparator<T>>, start?: number, end?: number): number;
export declare function sortedInsert<T>(sortedArray: ReadonlyArray<T>, item: Readonly<T>, comparators: ReadonlyArray<Comparator<T>>): ReadonlyArray<T>;
export declare function get<T>(array: ReadonlyArray<T>, index: number, outOfBoundsValue: T): T;
export declare function repeat<T>(item: T, count: number): T[];
export declare function zeroes(n: number): number[];
